<div id="{{ field.field_name }}-searchlet" class="searchlet">
  <h3 class="titles">{{ field.label }}</h3>
  <ul class="operators">
  {% for option in options %}
    <li><input id="{{ field.field_name }}{{ forloop.counter }}" type="radio" name="{{ field.field_name }}.operator" value="{{ option.operator }}"/>
        <label for="{{ field.field_name }}{{ forloop.counter }}">{{ option.label }}</label></li>
  {% endfor %}
  </ul>
  {% block widget %}
  <input class="search-term" type="text" name="{{ field.field_name }}" id="{{ field.field_name }}" value="" autocomplete="off" />
  {% endblock %}
</div>
