{% load i18n %}
<h4 class="title">{{ title }}
  <span class="query">{{ query|safe }}</span>
  <input class="search-action" type="submit" value="{% trans "Search" %}"/>
</h4>

<ul id="search-sections">
{% for field in fields %}
  <li><button class="search-section" searchlet="{{ field.field_name }}">{{ field.menuitem_label }}</button></li>
{% endfor %}
</ul>

{% for field in fields %}
  {{ field.render_searchlet_block|safe }}
{% endfor %}
