<div id="{{ field.field_name }}-searchlet" class="searchlet">
  <h3 class="titles">{{ field.label }}</h3>
  <div class="search-block">
  <select id="{{ field.field_name }}__{{ field.operator }}" name="{{ field.field_name }}__{{ field.operator }}" size="{{ field.select_size }}" multiple="true">
  {% for option in options %}
    <option value="{{ option.operator }}">{{ option.label }}</option>
  {% endfor %}
  </select>
  </div>
</div>
