/* Styles for the search form */

#search-sections {
    display: none;
    float: left;
    list-style: none;
    padding: 0px;
}

#search-sections li {
    padding: 0px;
    margin: 0px;
}

.search-section {
    border: 0;
    background: transparent;
    cursor: pointer;
    padding-left: 0px;
}

.searchlet {
    float: left;
}

.text-matching-type {
    list-style: none;
}

/* Query styles */

button.remove-action {
    visibility: hidden;
    background: transparent url(../img/remove-icon.png) 50% 50% no-repeat;
    border: 0;
    text-indent: -999em;
    width: 10px;
    margin-left: 2px;
    margin-right: 0;
    cursor: pointer;
}

.show-button button.remove-action {
    visibility: visible;
}

.query-arg a, .query-arg a span {
    text-decoration: none;
    font-weight: bold;
}

.query-arg a:hover, .query-arg a:hover span {
    text-decoration: underline;
}


form input.search-action {
    text-align: center;
    border: none;
    font-size: 10px;
    padding-top: 3px;
    text-indent: -999em;
    background: transparent url(../img/buscar_boton.png) top left;
    width: 74px;
    height: 23px;
}


/* Easy select styles */

.search-block {
    float: left;
}

.search-block select {
    width: 100%;
}

.add-remove-buttons {
    float: left;
    text-align: center;
}

.add-remove-buttons button {
    background:transparent none repeat scroll 0 0;
    border:medium none;
    margin: 0 12px;
}

.add-remove-buttons button.add {
    background:url(../img/flecha_right.png) center no-repeat;
    font-size: 0pt;
    width: 11px;
    height: 11px;    
}

.add-remove-buttons button.delete {
    background:url(../img/flecha_left.png) center no-repeat;
    font-size: 1pt;
    width: 11px;
    height: 11px;
}

.search-block input, .search-block button {
    display: block;
}

.search-block button {
    background: none;
    border: none;
}
