{% load i18n %}
<link type="text/css" rel="stylesheet" href="{{ MEDIA_URL }}css/searchform.css" />
<script type="text/javascript" src="{{ MEDIA_URL }}js/jquery.smartsearch.js"></script>
<script type="text/javascript">
(function ($) {

  $(document).ready(function () {

    $("#search_form").smartsearch({
        separator: '{% trans "and" %}',
        remove_text: '{%  trans "remove" %}',
        description_map: {
            {% for field, prefix in form.get_fields_with_query_arg_prefixes %}'{{ field }}': '{{ prefix }}'{% if not forloop.last %},{% endif %}
            {% endfor %}
        }
    });

    $("#search_form button.search-section:first").click();

  });

})(jQuery);
</script>
